OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Αδυναμία εγγραφής στον κατάλογο \"config\"!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Αυτό μπορεί συνήθως να διορθωθεί παρέχοντας δικαιώματα εγγραφής για το φάκελο config στο διακομιστή δικτύου",
    "See %s" : "Δείτε %s",
    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Αυτό μπορεί συνήθως να διορθωθεί δίνοντας στον διακομιστή γραπτή πρόσβαση στον κατάλογο εκχώρησης. Βλέπε%s",
    "Sample configuration detected" : "Ανιχνεύθηκε δείγμα εγκατάστασης",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Έχει ανιχνευθεί ότι το δείγμα εγκατάστασης έχει αντιγραφεί. Αυτό μπορεί να σπάσει την εγκατάστασή σας και δεν υποστηρίζεται. Παρακαλώ διαβάστε την τεκμηρίωση πριν εκτελέσετε αλλαγές στο config.php",
    "%1$s and %2$s" : "%1$s και %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s και %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s και %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s και %5$s",
    "Education Edition" : "Εκπαιδευτική Έκδοση",
    "Enterprise bundle" : "Πακέτο επιχειρήσεων",
    "Groupware bundle" : "Ομάδα δέσμης",
    "Social sharing bundle" : "Πακέτο κοινωνικού διαμοιρασμού",
    "PHP %s or higher is required." : "PHP %s ή νεώτερη απαιτείται.",
    "PHP with a version lower than %s is required." : "Απαιτείται PHP παλαιότερη από την έκδοση %s.",
    "%sbit or higher PHP required." : "%sbit απαιτείται νεώτερη έκδοση PHP.",
    "Following databases are supported: %s" : " Υποστηρίζονται οι ακόλουθες βάσεις δεδομένων: %s",
    "The command line tool %s could not be found" : "Το εργαλείο γραμμής εντολών %s δεν μπορεί να βρεθεί",
    "The library %s is not available." : "Το %s της βιβλιοθήκης δεν είναι διαθέσιμο.",
    "Following platforms are supported: %s" : "Οι ακόλουθες πλατφόρμες υποστηρίζονται: %s",
    "Server version %s or higher is required." : "Απαιτείται έκδοση διακομιστή %s ή νεότερη.",
    "Server version %s or lower is required." : "Απαιτείται έκδοση διακομιστή %s ή παλαιότερη.",
    "Authentication" : "Πιστοποίηση",
    "Unknown filetype" : "Άγνωστος τύπος αρχείου",
    "Invalid image" : "Μη έγκυρη εικόνα",
    "Avatar image is not square" : "Η εικόνα του άβαταρ δεν είναι τετράγωνη",
    "today" : "σήμερα",
    "tomorrow" : "αύριο",
    "yesterday" : "χτες",
    "_in %n day_::_in %n days_" : ["σε %n ημέρα","σε %n ημέρες"],
    "_%n day ago_::_%n days ago_" : ["%n ημέρα πριν","%n ημέρες πριν"],
    "next month" : "επόμενος μήνας",
    "last month" : "τελευταίο μήνα",
    "_in %n month_::_in %n months_" : ["σε %n μήνα","σε %n μήνες"],
    "_%n month ago_::_%n months ago_" : ["πριν %n μήνα","πριν %n μήνες"],
    "next year" : "επόμενος χρόνος",
    "last year" : "τελευταίο χρόνο",
    "_%n year ago_::_%n years ago_" : ["%n χρόνο πριν","%n χρόνια πριν"],
    "_%n hour ago_::_%n hours ago_" : ["%nώρα πριν","%nώρες πριν"],
    "_%n minute ago_::_%n minutes ago_" : ["%nλεπτό πριν","%nλεπτά πριν"],
    "in a few seconds" : "σε λίγα δευτερόλεπτα",
    "seconds ago" : "δευτερόλεπτα πριν",
    "Empty file" : "Κενό αρχείο",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Το άρθρωμα με ID: %sδεν υπάρχει. Παρακαλούμε ενεργοποιήστε το στις ρυθμίσεις των εφαρμογών σας ή επικοινωνήστε με τον διαχειριστή.",
    "File name is a reserved word" : "Το όνομα αρχείου είναι λέξη που έχει δεσμευτεί",
    "File name contains at least one invalid character" : "Το όνομα αρχείου περιέχει έναν τουλάχιστον μη έγκυρο χαρακτήρα",
    "File name is too long" : "Το όνομα αρχείου είνια πολύ μεγάλο",
    "Dot files are not allowed" : "Δεν επιτρέπονται αρχεία που ξεκινούν από τελεία - Dot ",
    "Empty filename is not allowed" : "Δεν επιτρέπεται άδειο όνομα αρχείου",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Η εφαρμογή \"%s\" δεν μπορεί να εγκατασταθεί διότι δεν είναι δυνατή η ανάγνωση του αρχείου appinfo.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Η εφαρμογή \"%s\" δεν μπορεί να εγκατασταθεί διότι δεν είναι συμβατή με την έκδοση του διακομιστή.",
    "__language_name__" : "Ελληνικά",
    "This is an automatically sent email, please do not reply." : "Αυτό είναι ένα μήνυμα ηλεκτρονικού ταχυδρομείου που στάλθηκε αυτόματα, παρακαλούμε μην απαντήσετε.",
    "Help" : "Βοήθεια",
    "Apps" : "Εφαρμογές",
    "Settings" : "Ρυθμίσεις",
    "Log out" : "Έξοδος",
    "Users" : "Χρήστες",
    "Unknown user" : "Άγνωστος χρήστης",
    "Overview" : "Επισκόπηση",
    "Basic settings" : "Βασικές ρυθμίσεις",
    "Sharing" : "Διαμοιρασμός",
    "Security" : "Ασφάλεια",
    "Additional settings" : "Επιπρόσθετες ρυθμίσεις",
    "Personal info" : "Προσωπικές πληροφορίες",
    "%s enter the database username and name." : "%sπληκτρολογήστε όνομα χρήστη και όνομα βάσης δεδομένων.",
    "%s enter the database username." : "%s εισάγετε το όνομα χρήστη της βάσης δεδομένων.",
    "%s enter the database name." : "%s εισάγετε το όνομα της βάσης δεδομένων.",
    "%s you may not use dots in the database name" : "%s μάλλον δεν χρησιμοποιείτε τελείες στο όνομα της βάσης δεδομένων",
    "Oracle connection could not be established" : "Αδυναμία σύνδεσης Oracle",
    "Oracle username and/or password not valid" : "Μη έγκυρος χρήστης και/ή συνθηματικό της Oracle",
    "PostgreSQL username and/or password not valid" : "Μη έγκυρος χρήστης και/ή συνθηματικό της PostgreSQL",
    "You need to enter details of an existing account." : "Χρειάζεται να εισάγετε λεπτομέρειες από υπάρχον λογαριασμό.",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Το Mac OS X δεν υποστηρίζεται και το %s δεν θα λειτουργήσει σωστά σε αυτή την πλατφόρμα. Χρησιμοποιείτε με δική σας ευθύνη!",
    "For the best results, please consider using a GNU/Linux server instead." : "Για καλύτερα αποτελέσματα, παρακαλούμε εξετάστε την μετατροπή σε έναν διακομιστή GNU/Linux.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Φαίνεται ότι η εγκατάσταση %s εκτελείται σε περιβάλλον 32-bit PHP και η επιλογη open_basedir έχει ρυθμιστεί στο αρχείο php.ini. Αυτό θα οδηγήσει σε προβλήματα με αρχεία πάνω από 4 GB και δεν συνίσταται.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Παρακαλώ αφαιρέστε την ρύθμιση open_basedir μέσα στο αρχείο php.ini ή αλλάξτε σε 64-bit PHP.",
    "Set an admin username." : "Εισάγετε όνομα χρήστη διαχειριστή.",
    "Set an admin password." : "Εισάγετε συνθηματικό διαχειριστή.",
    "Can't create or write into the data directory %s" : "Αδύνατη η δημιουργία ή συγγραφή στον κατάλογο δεδομένων %s",
    "Invalid Federated Cloud ID" : "Μη έγκυρο Federated Cloud ID",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Το σύστημα διαμοιρασμού %s πρέπει να υλοποιεί την διεπαφή OCP\\Share_Backend",
    "Sharing backend %s not found" : "Το σύστημα διαμοιρασμού %s δεν βρέθηκε",
    "Sharing backend for %s not found" : "Το σύστημα διαμοιρασμού για το %s δεν βρέθηκε",
    "Open »%s«" : "Άνοιγμα »%s«",
    "%1$s via %2$s" : "%1$s μέσω %2$s",
    "You are not allowed to share %s" : "Δεν επιτρέπεται να διαμοιράσετε τον πόρο %s",
    "Can’t increase permissions of %s" : "Αδυναμία αύξησης των δικαιωμάτων του %s",
    "Files can’t be shared with delete permissions" : "Δεν μπορεί να γίνει διαμοιρασμός αρχείων με δικαιώματα διαγραφής",
    "Files can’t be shared with create permissions" : "Δεν μπορεί να γίνει διαμοιρασμός αρχείων με δικαιώματα δημιουργίας",
    "Expiration date is in the past" : "Η ημερομηνία λήξης είναι στο παρελθόν",
    "Can’t set expiration date more than %s days in the future" : "Δεν είναι δυνατό να τεθεί η ημερομηνία λήξης σε περισσότερες από %s ημέρες στο μέλλον",
    "%1$s shared »%2$s« with you." : "%1$s διαμοιράστηκε »%2$s« με εσάς.",
    "Click the button below to open it." : "Κάντε κλικ στο παρακάτω κουμπί για να το ανοίξετε.",
    "The requested share does not exist anymore" : "Το διαμοιρασμένο που ζητήθηκε δεν υπάρχει πλέον",
    "Could not find category \"%s\"" : "Αδυναμία εύρεσης κατηγορίας \"%s\"",
    "Sunday" : "Κυριακή",
    "Monday" : "Δευτέρα",
    "Tuesday" : "Τρίτη",
    "Wednesday" : "Τετάρτη",
    "Thursday" : "Πέμπτη",
    "Friday" : "Παρασκευή",
    "Saturday" : "Σάββατο",
    "Sun." : "Κυρ.",
    "Mon." : "Δευ.",
    "Tue." : "Τρί.",
    "Wed." : "Τετ.",
    "Thu." : "Πέμ.",
    "Fri." : "Παρ.",
    "Sat." : "Σαβ.",
    "Su" : "Κυ",
    "Mo" : "Δε",
    "Tu" : "Τρ",
    "We" : "Τε",
    "Th" : "Πε",
    "Fr" : "Πα",
    "Sa" : "Σα",
    "January" : "Ιανουάριος",
    "February" : "Φεβρουάριος",
    "March" : "Μάρτιος",
    "April" : "Απρίλιος",
    "May" : "Μάϊος",
    "June" : "Ιούνιος",
    "July" : "Ιούλιος",
    "August" : "Αύγουστος",
    "September" : "Σεπτέμβριος",
    "October" : "Οκτώβριος",
    "November" : "Νοέμβριος",
    "December" : "Δεκέμβριος",
    "Jan." : "Ιαν.",
    "Feb." : "Φεβ.",
    "Mar." : "Μαρ.",
    "Apr." : "Απρ.",
    "May." : "Μαι.",
    "Jun." : "Ιουν.",
    "Jul." : "Ιουλ.",
    "Aug." : "Αυγ.",
    "Sep." : "Σεπ.",
    "Oct." : "Οκτ.",
    "Nov." : "Νοε.",
    "Dec." : "Δεκ.",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Μόνο οι ακόλουθοι χαρακτήρες επιτρέπονται στο όνομα χρήστη;  \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"",
    "A valid username must be provided" : "Πρέπει να δοθεί έγκυρο όνομα χρήστη",
    "Username contains whitespace at the beginning or at the end" : "Το όνομα χρήστη περιέχει κενό διάστημα στην αρχή ή στο τέλος",
    "Username must not consist of dots only" : "Το όνομα χρήστη δεν πρέπει να περιέχει μόνο τελείες",
    "A valid password must be provided" : "Πρέπει να δοθεί έγκυρο συνθηματικό",
    "The username is already being used" : "Το όνομα χρήστη είναι κατειλημμένο",
    "User disabled" : "Ο χρήστης απενεργοποιήθηκε",
    "Login canceled by app" : "Η είσοδος ακυρώθηκε από την εφαρμογή",
    "a safe home for all your data" : "ένα ασφαλές μέρος για όλα τα δεδομένα σας",
    "File is currently busy, please try again later" : "Το αρχείο χρησιμοποιείται αυτή τη στιγμή, παρακαλώ προσπαθήστε αργότερα",
    "Can't read file" : "Αδυναμία ανάγνωσης αρχείου",
    "Application is not enabled" : "Δεν ενεργοποιήθηκε η εφαρμογή",
    "Authentication error" : "Σφάλμα πιστοποίησης",
    "Token expired. Please reload page." : "Το αναγνωριστικό έληξε. Παρακαλώ φορτώστε ξανά την σελίδα.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Δεν βρέθηκαν εγκατεστημένοι οδηγοί βάσεων δεδομένων (sqlite, mysql, or postgresql).",
    "Cannot write into \"config\" directory" : "Αδυναμία εγγραφής στον κατάλογο \"config\"",
    "Cannot write into \"apps\" directory" : "Αδυναμία εγγραφής στον κατάλογο \"apps\"",
    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the appstore in the config file. See %s" : "Αυτό συνήθως μπορεί να διορθωθεί δίνοντας δικαιώματα εγγραφής στον κατάλογο apps στον διακομιστή ιστού ή απενεργοποιώντας το appstore στο αρχείο διαμόρφωσης. Δείτε το %s",
    "Cannot create \"data\" directory" : "Αδυναμία δημιουργίας του καταλόγου \"data\"",
    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Αυτό μπορεί συνήθως να διορθωθεί δίνοντας στον διακομιστή ιστού δικαιώματα εγγραφής στον βασικό κατάλογο. Δείτε το%s",
    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Τα δικαιώματα πρόσβασης μπορούν συνήθως να διορθωθούν δίνοντας δικαιώματα εγγραφής στον βασικό κατάλογο στον διακομιστή ιστού. Δείτε το%s.",
    "Setting locale to %s failed" : "Ρύθμιση τοπικών ρυθμίσεων σε %s απέτυχε",
    "Please install one of these locales on your system and restart your webserver." : "Παρακαλώ να εγκαταστήσετε μία από αυτές τις τοπικές ρυθμίσεις στο σύστημά σας και να επανεκκινήσετε τον διακομιστή δικτύου σας.",
    "Please ask your server administrator to install the module." : "Παρακαλώ ζητήστε από το διαχειριστή του διακομιστή σας να εγκαταστήσει τη μονάδα.",
    "PHP module %s not installed." : "Η μονάδα %s PHP δεν είναι εγκατεστημένη. ",
    "PHP setting \"%s\" is not set to \"%s\"." : "Η ρύθμιση \"%s\"της PHP δεν είναι ορισμένη σε \"%s\".",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Προσαρμόζοντας αυτήν τη ρύθμιση στο php.ini το Nextcloud θα εκτελεστεί ξανά",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "Το mbstring.func_overload έχει ορισθεί σε \"%s\" αντί για την αναμενόμενη τιμή \"0\"",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Για να διορθώσετε αυτό το πρόβλημα ορίστε το <code>mbstring.func_overload</code> σε <code>0</code> στο αρχείο php.ini",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Απαιτείται τουλάχιστον το libxml2 2.7.0. Αυτή τη στιγμή είναι εγκατεστημένο το %s.",
    "To fix this issue update your libxml2 version and restart your web server." : "Για να διορθώσετε το σφάλμα ενημερώστε την έκδοση του libxml2 και επανεκκινήστε τον διακομιστή.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Η PHP φαίνεται να είναι ρυθμισμένη ώστε να αφαιρεί inline doc blocks. Αυτό θα καταστήσει πολλές βασικές εφαρμογές μη διαθέσιμες.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Αυτό πιθανόν προκλήθηκε από προσωρινή μνήμη (cache)/επιταχυντή όπως τη Zend OPcache ή τον eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "Κάποια αρθρώματα της PHP έχουν εγκατασταθεί, αλλά είναι ακόμα καταγεγραμμένες ως εκλιπόντα;",
    "Please ask your server administrator to restart the web server." : "Παρακαλώ ζητήστε από το διαχειριστή του διακομιστή σας να επανεκκινήσει το διακομιστή δικτύου σας.",
    "PostgreSQL >= 9 required" : "Απαιτείται PostgreSQL >= 9",
    "Please upgrade your database version" : "Παρακαλώ αναβαθμίστε την έκδοση της βάσης δεδομένων σας",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Παρακαλώ αλλάξτε τις ρυθμίσεις σε 0770 έτσι ώστε ο κατάλογος να μην μπορεί να προβάλλεται από άλλους χρήστες.",
    "Your data directory is readable by other users" : "Ο κατάλογος δεδομένων σας είναι διαθέσιμος προς ανάγνωση από άλλους χρήστες",
    "Your data directory must be an absolute path" : "Ο κατάλογος δεδομένων σας πρέπει να είναι απόλυτη διαδρομή",
    "Check the value of \"datadirectory\" in your configuration" : "Ελέγξτε την τιμή του \"Φάκελος Δεδομένων\" στις ρυθμίσεις σας",
    "Your data directory is invalid" : "Ο κατάλογος δεδομένων σας δεν είναι έγκυρος",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Εξασφαλίστε ότι υπάρχει ένα αρχείο με όνομα \".ocdata\" στον βασικό κατάλογο του καταλόγου δεδομένων.",
    "Could not obtain lock type %d on \"%s\"." : "Αδυναμία ανάκτησης τύπου κλειδιού %d στο \"%s\".",
    "Storage unauthorized. %s" : "Αποθηκευτικός χώρος χωρίς εξουσιοδότηση. %s",
    "Storage incomplete configuration. %s" : "Ελλιπής διαμόρφωση αποθηκευτικού χώρου. %s",
    "Storage connection error. %s" : "Σφάλμα σύνδεσης με αποθηκευτικό χώρο. %s",
    "Storage is temporarily not available" : "Μη διαθέσιμος χώρος αποθήκευσης προσωρινά",
    "Storage connection timeout. %s" : "Λήξη χρονικού ορίου σύνδεσης με αποθηκευτικό χώρο.%s",
    "Create" : "Δημιουργία",
    "Change" : "Αλλαγή",
    "Delete" : "Διαγραφή",
    "Share" : "Κοινή χρήση",
    "Unlimited" : "Απεριόριστα",
    "Verifying" : "Γίνεται επαλήθευση",
    "Verifying …" : "Γίνεται επαλήθευση ...",
    "Verify" : "Επαλήθευση",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "Αποτυχία διαμοιρασμού %s, γιατί το σύστημα υποστήριξης δεν επιτρέπει κοινόχρηστα τύπου %i",
    "Sharing %s failed, because the file does not exist" : "Ο διαμοιρασμός του %s απέτυχε, γιατί το αρχείο δεν υπάρχει",
    "Sharing %s failed, because you can not share with yourself" : "Ο διαμοιρασμός του %s απέτυχε, γιατί δεν μπορείτε να διαμοιραστείτε με τον εαυτό σας.",
    "Sharing %1$s failed, because this item is already shared with %2$s" : "Ο διαμοιρασμός του %1$s απέτυχε, γιατί το αντικείμενο είναι διαμοιρασμένο ήδη με τον χρήστη %2$s",
    "You need to provide a password to create a public link, only protected links are allowed" : "Πρέπει να εισάγετε έναν κωδικό για να δημιουργήσετε έναν δημόσιο σύνδεσμο. Μόνο προστατευμένοι σύνδεσμοι επιτρέπονται",
    "Sharing %s failed, because sharing with links is not allowed" : "Ο διαμοιρασμός του %s απέτυχε, γιατί δεν επιτρέπεται ο διαμοιρασμός με συνδέσμους",
    "Not allowed to create a federated share with the same user" : "Δεν επιτρέπεται η δημιουργία federated διαμοιρασμού με τον ίδιο χρήστη",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Δεν μπορεί να οριστεί ημερομηνία λήξης. Οι κοινοποιήσεις δεν μπορεί να λήγουν αργότερα από %s αφού έχουν διαμοιραστεί.",
    "Cannot set expiration date. Expiration date is in the past" : "Δεν μπορεί να οριστεί ημερομηνία λήξης. Η ημερομηνία λήξης είναι στο παρελθόν",
    "Sharing failed, because the user %s is the original sharer" : "Ο διαμοιρασμός του %s απέτυχε, γιατί το αντικείμενο είναι διαμοιρασμένο αρχικά από τον ίδιο χρήστη.",
    "Sharing %s failed, because resharing is not allowed" : "Ο διαμοιρασμός του %s απέτυχε, γιατί δεν επιτρέπεται ο επαναδιαμοιρασμός",
    "Sharing %s failed, because the file could not be found in the file cache" : "Ο διαμοιρασμός του %s απέτυχε, γιατί το αρχείο δεν βρέθηκε στην προσωρινή αποθήκευση αρχείων"
},
"nplurals=2; plural=(n != 1);");
